pub struct SigImplLink {
pub scope: ModPath,
pub name: CompactString,
pub sig_id: BindId,
pub impl_id: BindId,
}Expand description
Maps a val foo: T declaration in a .gxi interface to its
let foo = … implementation site in the paired .gx. Populated by
check_sig whenever it matches a sig proxy bind to its impl bind.
Used by IDE tooling to (a) goto-def from a sig val site to the impl,
and (b) union find-references results across both BindIds.
Only populated when env.lsp_mode is set.
Fields
scope: ModPathname: CompactStringsig_id: BindIdimpl_id: BindIdTrait Implementations
Sourceimpl Clone for SigImplLink
impl Clone for SigImplLink
Sourcefn clone(&self) -> SigImplLink
fn clone(&self) -> SigImplLink
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SigImplLink
impl RefUnwindSafe for SigImplLink
impl Send for SigImplLink
impl Sync for SigImplLink
impl Unpin for SigImplLink
impl UnsafeUnpin for SigImplLink
impl UnwindSafe for SigImplLink