Module typ

Module typ 

Structs

AbstractId
FnArgType
FnType
TVal
A value with it’s type, used for formatting
TVar
TypeRef
A reference to a named typedef, e.g. Foo or Result<i64, string>. pos and ori are IDE metadata recording where this reference was written in source — they’re populated by the parser and ignored for type-system equality, ordering and hashing so they don’t affect type identity.

Enums

FnArgKind
Position vs label distinction for a function argument.
Type