Type

Enum Type 

pub enum Type {
Show 15 variants Bottom, Any, Primitive(BitFlags<Typ>), Ref { scope: ModPath, name: ModPath, params: Arc<[Type]>, }, Fn(Arc<FnType>), Set(Arc<[Type]>), TVar(TVar), Error(Arc<Type>), Array(Arc<Type>), ByRef(Arc<Type>), Tuple(Arc<[Type]>), Struct(Arc<[(ArcStr, Type)]>), Variant(ArcStr, Arc<[Type]>), Map { key: Arc<Type>, value: Arc<Type>, }, Abstract { id: AbstractId, params: Arc<[Type]>, },
}

Variants



Bottom



Any



Primitive(BitFlags<Typ>)



Ref

Fields

scope: ModPath
name: ModPath
params: Arc<[Type]>


Fn(Arc<FnType>)



Set(Arc<[Type]>)



TVar(TVar)



Error(Arc<Type>)



Array(Arc<Type>)



ByRef(Arc<Type>)



Tuple(Arc<[Type]>)



Struct(Arc<[(ArcStr, Type)]>)



Variant(ArcStr, Arc<[Type]>)



Map

Fields

key: Arc<Type>
value: Arc<Type>


Abstract

Fields

params: Arc<[Type]>

Implementations

Source

impl Type

pub fn check_cast(&self, env: &Env) -> Result<()>

pub fn cast_value(&self, env: &Env, v: Value) -> Value

pub fn is_a(&self, env: &Env, v: &Value) -> bool

return true if v is structurally compatible with the type

Source

impl Type

pub fn check_contains(&self, env: &Env, t: &Self) -> Result<()>

pub fn contains(&self, env: &Env, t: &Self) -> Result<bool>

pub fn contains_with_flags( &self, flags: BitFlags<ContainsFlags>, env: &Env, t: &Self, ) -> Result<bool>

Source

impl Type

pub fn could_match(&self, env: &Env, t: &Self) -> Result<bool>

pub fn sig_matches( &self, env: &Env, impl_type: &Self, adts: &FxHashMap<AbstractId, Type>, ) -> Result<()>

Source

impl Type

pub fn union(&self, env: &Env, t: &Self) -> Result<Self>

pub fn diff(&self, env: &Env, t: &Self) -> Result<Self>

Source

impl Type

pub fn unfreeze_tvars(&self)

pub fn alias_tvars(&self, known: &mut FxHashMap<ArcStr, TVar>)

alias type variables with the same name to each other

pub fn collect_tvars(&self, known: &mut FxHashMap<ArcStr, TVar>)

pub fn check_tvars_declared(&self, declared: &FxHashSet<ArcStr>) -> Result<()>

pub fn has_unbound(&self) -> bool

pub fn bind_as(&self, t: &Self)

bind all unbound type variables to the specified type

pub fn reset_tvars(&self) -> Type

return a copy of self with all type variables unbound and unaliased. self will not be modified

pub fn replace_tvars(&self, known: &FxHashMap<ArcStr, Self>) -> Type

return a copy of self with every TVar named in known replaced with the corresponding type. TVars not in known are replaced with fresh TVars using unique names to avoid entanglement with the caller’s TVars that happen to share the same name.

Source

impl Type

pub fn empty_tvar() -> Self

pub fn is_defined(&self) -> bool

pub fn lookup_ref(&self, env: &Env) -> Result<Type>

pub fn any() -> Self

pub fn boolean() -> Self

pub fn number() -> Self

pub fn int() -> Self

pub fn uint() -> Self

pub fn strip_error(&self, env: &Env) -> Option<Self>

remove the outer error type and return the inner payload, fail if self isn’t an error or contains non error types

pub fn is_bot(&self) -> bool

pub fn with_deref<R, F: FnOnce(Option<&Self>) -> R>(&self, f: F) -> R

pub fn scope_refs(&self, scope: &ModPath) -> Type