Structs
- Abstract
Id - FnArg
Type - FnType
- TVal
- A value with it’s type, used for formatting
- TVar
- TypeRef
- A reference to a named typedef, e.g.
FooorResult<i64, string>.posandoriare IDE metadata recording where this reference was written in source — they’re populated by the parser and ignored for type-system equality, ordering and hashing so they don’t affect type identity.